"""Slices CLI authentication."""


import typer
from rich import print

from .config import auth_file_location, delete_auth_token, parse_auth_token, save_auth_token
from .context import Context
from .oauth2.flow import AuthenticationFlow, DeviceFlow

auth_app = typer.Typer(help="User authentication")


@auth_app.command(help="Authenticate and retrieve credentials")
def login(no_browser: bool = True):
    """Authenticate and retrieve credentials."""

    if no_browser:
        flow = DeviceFlow()
        token = flow.perform_login_flow()
    else:
        flow = AuthenticationFlow()
        token = flow.perform_login_flow()

    if token:
        save_auth_token(token)

        auth_info = parse_auth_token(token)
        print(f"[bold green]Successfully logged in as '{auth_info['preferred_username']}' ")
        print(f":floppy_disk: Saved to {auth_file_location}")
    else:
        print("[red]Logging in failed. :x:")


@auth_app.command(help="Show user credentials.")
def show(
    ctx: Context,
):
    """Show user credentials."""
    user_info = ctx.obj.user_info

    if user_info:
        print(f"Logged in as '{user_info['preferred_username']}'")
    else:
        print("[red]Not logged in. :x:")
        raise typer.Exit


@auth_app.command(help="Remove user credentials")
def logout():
    """Remove user credentials."""
    delete_auth_token()
    print("[bold green]Successfully logged out.[/] :white_check_mark:")
    print(f":floppy_disk: Deleted {auth_file_location}")
