"""Utility to follow progress of a BI task."""

from time import sleep

from rich.progress import Progress
from slices_bi_client.api.tasks_api import TasksApi


def follow_progress(
    bi_tasks_api: TasksApi,
    task_id,
    task_description_prefix,
    *,
    transient=False,
):
    """Periodically query BI tasks API to check on task while showing progress bar."""
    with Progress(transient=transient) as progress:
        progress_task = progress.add_task(task_description_prefix, total=None)

        task_finished = False
        next_log_line_nr = 0
        while not task_finished:
            task_progress = bi_tasks_api.get_task(task_id)
            progress.update(
                progress_task,
                total=task_progress.total,
                completed=task_progress.completed,
            )
            if task_progress.description:
                progress.update(
                    progress_task,
                    description=f"{task_description_prefix}: {task_progress.description}",
                )
            task_finished = task_progress.status in ("finished", "failed")

            task_logs = bi_tasks_api.get_task_logs(task_id, start=next_log_line_nr)
            if len(task_logs):
                next_log_line_nr = task_logs[-1].n + 1
                progress.log(*(line.t for line in task_logs), sep="\n")

            if not task_finished:
                sleep(1)
